API
==============

.. automodule:: pyeodh
   :members:
   :exclude-members: Client
   :undoc-members:
   :show-inheritance:

.. automodule:: pyeodh.client
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: pyeodh.resource_catalog
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: pyeodh.ades
   :members:
   :undoc-members:
   :show-inheritance: